@@ -78,9 +78,9 @@ struct cucd::Service::Private : public QObject
               registry(registry),
               app_manager(application_manager)
     {
-        unityFocus = new QDBusInterface("com.canonical.Unity.FocusInfo" /* service */,
-                                        "/com/canonical/Unity/FocusInfo" /* object path */,
-                                        "com.canonical.Unity.FocusInfo" /* interface */,
+        shellFocus = new QDBusInterface("com.lomiri.Shell.FocusInfo" /* service */,
+                                        "/com/lomiri/Shell/FocusInfo" /* object path */,
+                                        "com.lomiri.Shell.FocusInfo" /* interface */,
                                         QDBusConnection::sessionBus(),
                                         this);
     }
@@ -92,7 +92,7 @@ struct cucd::Service::Private : public QObject
     QStringList pasteFormats;
     QSet<RegHandler*> handlers;
     QSharedPointer<cua::ApplicationManager> app_manager;
-    QDBusInterface *unityFocus;
+    QDBusInterface *shellFocus;
     const int maxActivePastes = 5;
 };
 
@@ -768,5 +768,5 @@ bool cucd::Service::verifiedSurfaceIsFocused(const QString &surfaceId)
     if (!qgetenv("CONTENT_HUB_TESTING").isNull())
         return true;
 
-    return d->unityFocus->call("isSurfaceFocused", surfaceId).arguments().at(0).toBool();
+    return d->shellFocus->call("isSurfaceFocused", surfaceId).arguments().at(0).toBool();
 }
